@@@@@@@@@@
dob-bright
@@@@@@@@@@

.. CXREF:
   https://docs.github.com/en/actions/monitoring-and-troubleshooting-workflows/adding-a-workflow-status-badge

.. image:: https://github.com/doblabs/dob-bright/actions/workflows/checks-unspecial.yml/badge.svg?branch=release
  :target: https://github.com/doblabs/dob-bright/actions/workflows/checks-unspecial.yml/badge.svg?branch=release
  :alt: Build Status

.. CXREF: https://app.codecov.io/github.com/doblabs/dob-bright/settings/badge

.. image:: https://codecov.io/gh/doblabs/dob-bright/branch/release/graph/badge.svg?token=Q0USPP5UQ6
  :target: https://app.codecov.io/gh/doblabs/dob-bright
  :alt: Coverage Status

.. image:: https://readthedocs.org/projects/dob-bright/badge/?version=latest
  :target: https://dob-bright.readthedocs.io/en/latest/
  :alt: Documentation Status

.. image:: https://img.shields.io/github/v/release/doblabs/dob-bright.svg?style=flat
  :target: https://github.com/doblabs/dob-bright/releases
  :alt: GitHub Release Status

.. image:: https://img.shields.io/pypi/v/dob-bright.svg
  :target: https://pypi.org/project/dob-bright/
  :alt: PyPI Release Status

.. image:: https://img.shields.io/pypi/pyversions/dob-bright.svg
  :target: https://pypi.org/project/dob-bright/
  :alt: PyPI Supported Python Versions

.. image:: https://img.shields.io/github/license/doblabs/dob-bright.svg?style=flat
  :target: https://github.com/doblabs/dob-bright/blob/release/LICENSE
  :alt: License Status

|

.. |dob| replace:: ``dob``
.. _dob: https://github.com/tallybark/dob

.. |dob-docs| replace:: Dob documentation
.. _dob-docs: https://dob.readthedocs.io/en/latest/

.. |dob-bright| replace:: ``dob-bright``
.. _dob-bright: https://github.com/tallybark/dob-bright

|dob-bright|_ is a component of |dob|_,  an interactive, terminal-based,
time tracking, journaling, note-taking, and life-hacking application.

|dob-bright|_ provides the basic, non interesting functionality used
by the various |dob|_ components, such as the CLI user configuration
settings, the ``nark.Control`` shim, some basic terminal I/O methods,
and some (packaged) test infrastructure shared with other projects.

Please see the |dob-docs|_ for lots more help and instruction.

